@@ -15,7 +15,7 @@ krscvNOMAD <- function(xz,
                        degree.min=0, 
                        segments.min=1, 
                        complexity=c("degree-knots","degree","knots"),
-                       knots=c("quantiles","uniform"),
+                       knots=c("quantiles","uniform", "auto"),
                        basis=c("additive","tensor","glp","auto"),
                        cv.func=c("cv.ls","cv.gcv","cv.aic"),
                        degree=degree,
@@ -124,75 +124,76 @@ krscvNOMAD <- function(xz,
 
             basis.opt <-  basis;
             if(basis=="auto"){
-                basis.opt <- "additive"
-                cv <- cv.kernel.spline(x=x,
-                                       y=y,
-                                       z=z,
-                                       K=K,
-                                       lambda=lambda,
-                                       z.unique=z.unique,
-                                       ind=ind,
-                                       ind.vals=ind.vals,
-                                       nrow.z.unique=nrow.z.unique,
-                                       is.ordered.z=is.ordered.z,
-                                       knots=knots,
-                                       basis=basis.opt,
-                                       cv.func=cv.func)
-
-                cv.tensor <- cv.kernel.spline(x=x,
-                                              y=y,
-                                              z=z,
-                                              K=K,
-                                              lambda=lambda,
-                                              z.unique=z.unique,
-                                              ind=ind,
-                                              ind.vals=ind.vals,
-                                              nrow.z.unique=nrow.z.unique,
-                                              is.ordered.z=is.ordered.z,
-                                              knots=knots,
-                                              basis="tensor",
-                                              cv.func=cv.func)
-                if(cv > cv.tensor){
-                    cv <- cv.tensor
-                    basis.opt <-"tensor"
-                }
-
-                cv.glp <- cv.kernel.spline(x=x,
-                                              y=y,
-                                              z=z,
-                                              K=K,
-                                              lambda=lambda,
-                                              z.unique=z.unique,
-                                              ind=ind,
-                                              ind.vals=ind.vals,
-                                              nrow.z.unique=nrow.z.unique,
-                                              is.ordered.z=is.ordered.z,
-                                              knots=knots,
-                                              basis="glp",
-                                              cv.func=cv.func)
-                if(cv > cv.glp){
-                    cv <- cv.glp
-                    basis.opt <-"glp"
-                }
-
+              basis.opt <- "additive"
+              
+              cv <- cv.kernel.spline.wrapper(x=x,
+                                             y=y,
+                                             z=z,
+                                             K=K,
+                                             lambda=lambda,
+                                             z.unique=z.unique,
+                                             ind=ind,
+                                             ind.vals=ind.vals,
+                                             nrow.z.unique=nrow.z.unique,
+                                             is.ordered.z=is.ordered.z,
+                                             knots=knots,
+                                             basis=basis.opt,
+                                             cv.func=cv.func)
+              
+              cv.tensor <- cv.kernel.spline.wrapper(x=x,
+                                                    y=y,
+                                                    z=z,
+                                                    K=K,
+                                                    lambda=lambda,
+                                                    z.unique=z.unique,
+                                                    ind=ind,
+                                                    ind.vals=ind.vals,
+                                                    nrow.z.unique=nrow.z.unique,
+                                                    is.ordered.z=is.ordered.z,
+                                                    knots=knots,
+                                                    basis="tensor",
+                                                    cv.func=cv.func)
+              if(cv > cv.tensor){
+                cv <- cv.tensor
+                basis.opt <-"tensor"
+              }
+              
+              cv.glp <- cv.kernel.spline.wrapper(x=x,
+                                                 y=y,
+                                                 z=z,
+                                                 K=K,
+                                                 lambda=lambda,
+                                                 z.unique=z.unique,
+                                                 ind=ind,
+                                                 ind.vals=ind.vals,
+                                                 nrow.z.unique=nrow.z.unique,
+                                                 is.ordered.z=is.ordered.z,
+                                                 knots=knots,
+                                                 basis="glp",
+                                                 cv.func=cv.func)
+              if(cv > cv.glp){
+                cv <- cv.glp
+                basis.opt <-"glp"
+              }
+              
             } else {
-                cv <- cv.kernel.spline(x=x,
-                                       y=y,
-                                       z=z,
-                                       K=K,
-                                       lambda=lambda,
-                                       z.unique=z.unique,
-                                       ind=ind,
-                                       ind.vals=ind.vals,
-                                       nrow.z.unique=nrow.z.unique,
-                                       is.ordered.z=is.ordered.z,
-                                       knots=knots,
-                                       basis=basis.opt,
-                                       cv.func=cv.func)
+              cv <- cv.kernel.spline.wrapper(x=x,
+                                             y=y,
+                                             z=z,
+                                             K=K,
+                                             lambda=lambda,
+                                             z.unique=z.unique,
+                                             ind=ind,
+                                             ind.vals=ind.vals,
+                                             nrow.z.unique=nrow.z.unique,
+                                             is.ordered.z=is.ordered.z,
+                                             knots=knots,
+                                             basis=basis.opt,
+                                             cv.func=cv.func)
             }
-
+            
             attr(cv, "basis.opt")<-basis.opt
-
+            
             console <- newLineConsole()
             console <- printClear(console)
             console <- printPop(console)
@@ -295,8 +296,15 @@ krscvNOMAD <- function(xz,
                           print.output=print.output, 
                           params=params);
 
-        if(basis == "auto") 
-        attr(solution, "basis.opt") <- attributes(eval.cv(solution$solution, params))$basis.opt
+				if(basis == "auto"){
+						cv.basis <- eval.cv(solution$solution, params)
+						attr(solution, "basis.opt") <- attributes(cv.basis)$basis.opt
+						if(knots == "auto") 
+								attr(solution, "knots.opt") <- attributes(cv.basis)$knots.opt 
+				} 
+				else if (knots == "auto") 
+						attr(solution, "knots.opt") <- attributes(eval.cv(solution$solution, params))$knots.opt
+
 
         solution$degree.max.vec <- degree.max.vec
         
@@ -449,6 +457,10 @@ krscvNOMAD <- function(xz,
     basis.opt <- basis
     if(basis == "auto") basis.opt <- attributes(nomad.solution)$basis.opt
 
+		knots.opt <- knots
+    if(knots == "auto") knots.opt <- attributes(nomad.solution)$knots.opt
+
+
     ## Check for lambda of zero (or less) as solution as lm() with
     ## weights= will fail, so set to machine epsilon in this case
 
@@ -483,7 +495,7 @@ krscvNOMAD <- function(xz,
           degree.min=degree.min, 
           segments.min=segments.min, 
           complexity=complexity,
-          knots=knots,
+          knots=knots.opt,
           degree=degree,
           segments=segments,
           restarts=nmulti,
